"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareReference = exports.prepareReportName = exports.throwOnApiError = void 0;
const moment_1 = __importDefault(require("moment"));
async function throwOnApiError(apiResult) {
    const { response, value } = await apiResult;
    if (response.status >= 400) {
        console.error("[TestRail] Error during API request");
        throw {
            url: response.url,
            status: response.status,
            message: value,
        };
    }
    return Promise.resolve({ response, value });
}
exports.throwOnApiError = throwOnApiError;
const prepareReportName = (config, branch, buildNo, userAgents) => {
    const date = moment_1.default().format(config.dateFormat);
    return config.runName
        .replace("%BRANCH%", branch)
        .replace("%BUILD%", buildNo)
        .replace("%DATE%", date)
        .replace("%AGENTS%", `(${userAgents.join(", ")})`);
};
exports.prepareReportName = prepareReportName;
const prepareReference = (config, branch, buildNo) => {
    return config.reference
        ? config.reference.replace("%BRANCH%", branch).replace("%BUILD%", buildNo)
        : "";
};
exports.prepareReference = prepareReference;
